import unittest
import os
import tests

from checkout_sdk import logger


class CheckoutSdkTestCase(unittest.TestCase):
    def setUp(self):
        super().setUp()
        print('\n')

    def tearDown(self):
        super().tearDown()
        print('\n')
